package com.qs.mp.web.controller.api.admin;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qs.mp.admin.domain.Ticket;
import com.qs.mp.admin.domain.TicketBox;
import com.qs.mp.admin.domain.param.TicketBoxCreateParam;
import com.qs.mp.admin.service.ITicketBoxService;
import com.qs.mp.channel.domain.Channel;
import com.qs.mp.channel.domain.param.ChannelParam;
import com.qs.mp.channel.domain.vo.ChannelVO;
import com.qs.mp.channel.service.IChannelService;
import com.qs.mp.channel.service.IChannelUserRelService;
import com.qs.mp.common.constant.UserConstants;
import com.qs.mp.common.core.domain.AjaxResult;
import com.qs.mp.common.core.page.TableDataInfo;
import com.qs.mp.common.enums.ChannelRoleEnum;
import com.qs.mp.common.enums.ErrorCodeEnum;
import com.qs.mp.common.enums.TicketTypeEnum;
import com.qs.mp.system.service.ISysUserService;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import ma.glasnost.orika.MapperFacade;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @auther zhongcp
 * @create 2022-02-28 16:17:48
 * @describe 盲票管理前端控制器
 */
@Api("渠道管理API")
@RestController
@RequestMapping("/api/v1/mp/admin/ticket/box/*")
@Component
public class TicketBoxMgrController extends BaseApiController {

	@Autowired
	private ITicketBoxService ticketBoxService;

	@Autowired
	private IChannelUserRelService channelUserRelService;

	@Autowired
	private ISysUserService userService;

	@Autowired
	private MapperFacade mapperFacade;


	/**
	 * 查询所有盲票组列表
	 *
	 * @return
	 */
	@PostMapping("/list")
	public TableDataInfo list(@RequestBody TicketBox ticketBox) {
		startPage();
		List<TicketBox> list = ticketBoxService.list(new QueryWrapper<>());
		return getDataTable(list);
	}

	/**
	 * 新增盲票
	 * @param
	 * @return
	 */
	@ApiOperation(value = "新增盲票", notes = "管理端创建盲票")
	@PostMapping("/create")
	public AjaxResult create(@Validated @RequestBody TicketBoxCreateParam param) {

		if (param.getType() == TicketTypeEnum.OFFLINE) {
			if (param.getPkgSalePrice() == null || param.getPkgSalePrice() == 0 ) {
				return AjaxResult.error("采购单价必须大于0");
			}
			if (param.getPkgUnit() == null || param.getPkgUnit() == 0) {
				return AjaxResult.error("每包张数必须大于0");
			}
		}
		return AjaxResult.success();
	}

}
